User prompt
when mouse hovers over coffee, make coffee bigger
User prompt
when coffee is clicked, the counter on coffee increases by 1, and the global score decreases by 32
User prompt
make coffee clickable
User prompt
add a counter on the coffee, when coffee is clicked, this counter increases, and the global conter is multiplied by 4
User prompt
rename the button to coffee. it can be clicked on only when its opacity is 100%
Code edit (2 edits merged)
Please save this source code
User prompt
move the button to 100 px right
Code edit (1 edits merged)
Please save this source code
User prompt
when clicked on the coffe button, the count increases by 2
User prompt
Please fix the bug: 'code is not defined' in or related to this line: 'var codeTxt = new Text2(code.toString(), {' Line Number: 63
User prompt
the button changes from 20% opacity to 100% opacity, when the points reach 20 ↪💡 Consider importing and using the following plugins: @upit/tween.v1
User prompt
move the button to the bottom left
User prompt
Please fix the bug: 'Uncaught ReferenceError: codeIncrement is not defined' in or related to this line: 'code += codeIncrement;' Line Number: 81
User prompt
add a button class. put a button on the top left, which can be bought, and once bought, increases the coding count 2x
User prompt
place the buttons at the lower bottom
User prompt
add 4 buttons on the bottom, that are activated at 100 points, 400 points, 1000 points, 2000 points
User prompt
Please fix the bug: 'Uncaught TypeError: Cannot read properties of undefined (reading 'then')' in or related to this line: 'tween(coder, {' Line Number: 52 ↪💡 Consider importing and using the following plugins: @upit/tween.v1
User prompt
make "coder" pop every time mouse is clicked
User prompt
name the counter on the top : "code"
User prompt
import tween.v1 ↪💡 Consider importing and using the following plugins: @upit/tween.v1
User prompt
whenver the mouse is clicked, make the player slightly bigger, and then return to nomal size ↪💡 Consider importing and using the following plugins: @upit/tween.v1
User prompt
add a counter on the top, that increases by 4 points everytime mouse is clicked
User prompt
whenver mouse is clicked, the sound clicking is triggered
User prompt
the text is visible on the screen, with code increasing every 4 points for every second
User prompt
add a counter on the top center called code, which increases by 4 points
===================================================================
--- original.js
+++ change.js
@@ -26,22 +26,22 @@
anchorY: 0.5,
x: 1024,
y: 1366
});
-// Initialize score counter
-var score = 0;
-var scoreTxt = new Text2(score.toString(), {
+// Initialize code counter
+var code = 0;
+var codeTxt = new Text2(code.toString(), {
size: 150,
fill: 0xFFFFFF
});
-scoreTxt.anchor.set(0.5, 0);
-LK.gui.top.addChild(scoreTxt);
+codeTxt.anchor.set(0.5, 0);
+LK.gui.top.addChild(codeTxt);
game.down = function (x, y, obj) {
LK.getSound('typing').play();
- // Increase score by 4 every click
- score += 4;
- // Update score display
- scoreTxt.setText(score.toString());
+ // Increase code by 4 every click
+ code += 4;
+ // Update code display
+ codeTxt.setText(code.toString());
// Increase the size of the coder when clicked
tween(coder, {
scaleX: 1.2,
scaleY: 1.2
a developer sitting on his laptop in his cubicle, typing on the keyboard. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows
coffee mug. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows
coffee cup 8 bit. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows